#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 boxes
version:              0.1.5
visibility:           public
id:                   boxes-0.1.5-2Yds5Er5r2KHZ4UD7ucpYt
key:                  boxes-0.1.5-2Yds5Er5r2KHZ4UD7ucpYt
license:              BSD-3-Clause
maintainer:           David Feuer <David.Feuer@gmail.com>
author:               Brent Yorgey
synopsis:             2D text pretty-printing library
description:
    A pretty-printing library for laying out text in
    two dimensions, using a simple box model.

category:             Text
abi:                  9e9706785cc3156664f6ac96965447fc
exposed:              True
exposed-modules:      Text.PrettyPrint.Boxes
import-dirs:          /usr/lib/ghc-9.6.6/site-local/boxes-0.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/boxes-0.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/boxes-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-boxes
hs-libraries:         HSboxes-0.1.5-2Yds5Er5r2KHZ4UD7ucpYt
depends:              base-4.18.2.1 split-0.2.5-Bi3HfS9SciuGUuXE3PHa4h
haddock-interfaces:   /usr/share/doc/haskell-boxes/html/boxes.haddock
haddock-html:         /usr/share/doc/haskell-boxes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

